<template>
  <el-bus-crud ref="crud" v-bind="tableConfig"></el-bus-crud>
</template>

<script>
import { getAuditForm } from '@/utils/form-item-config'
export default {
  data() {
    return {
      tableConfig: {
        url: 'flower/api/partner/page',
        hasNew: false,
        hasDelete: false,
        editUrl: 'flower/api/partner/page/change/area',
        beforeOpen: (row, isNew) => {
          if (!isNew) {
            const district = this.getDistrict(row)
            row.district = district
            row.districtStr = district
          }
        },
        operationAttrs: {
          width: '200px',
          fixed: 'right',
        },
        columns: [
          { label: '合伙人名称', prop: 'name', minWidth: 120, fixed: 'left' },
          {
            label: '服务地区',
            formatter: (row) => this.getDistrict(row),
            minWidth: 200,
          },
          {
            label: '联系方式',
            prop: 'contactTel',
            minWidth: 150,
          },
          { label: '注册时间', prop: 'createTime', minWidth: '180px' },
          {
            label: '审核时间',
            prop: 'passTime',
            minWidth: 180,
          },
          {
            label: '状态',
            prop: 'statusStr',
            minWidth: 150,
          },
          {
            label: '启用/禁用',
            formatter: (row) => (
              <el-switch
                value={row.isEnabled}
                onChange={this.onEnabledChange.bind(this, row)}
              ></el-switch>
            ),
            minWidth: 120,
            fixed: 'right',
          },
        ],
        searchForm: [
          {
            type: 'row',
            items: [
              {
                label: '合伙人名称',
                id: 'name',
                type: 'input',
              },
              {
                label: '手机号',
                id: 'tel',
                type: 'input',
              },
              {
                label: '申请日期',
                component: 'el-bus-date-range',
                id: 'createDateBeginStr',
                commonFormat: true,
                commonFormatProps: ['createDateBeginStr', 'createDateEndStr'],
                customClass: 'in-bus-form',
              },
              {
                label: '服务地区',
                id: 'province',
                component: 'el-bus-select-area',
                el: {
                  clearable: true,
                },
                commonFormat: true,
                commonFormatProps: ['province', 'city', 'region'],
                customClass: 'in-bus-form',
              },
              {
                label: '状态',
                id: 'status',
                type: 'bus-select-dict',
                el: {
                  code: 'supplier_status',
                  clearable: true,
                  style: 'width:100%',
                },
              },
              {
                label: '启动/禁用',
                id: 'isEnabled',
                type: 'bus-select-dict',
                el: {
                  code: 'USER_ENABLED_OR_DISABLED',
                  clearable: true,
                  style: 'width:100%',
                },
              },
            ],
          },
        ],
        form: [
          { label: '合伙人名称：', id: 'name', type: 'input', readonly: true },
          {
            label: '服务地区：',
            id: 'district',
            type: 'bus-cascader',
            el: {
              otherInterfaceUri: 'flower/api/pub/china/area/json',
              props: {
                label: 'name',
                value: 'code',
                multiple: true,
              },
              filterOptions: (list) => {
                if (typeof list === 'string') {
                  return JSON.parse(list)
                }
                return list
              },
              style: 'width:100%',
            },
            inputFormat: (row) => {
              if ('province' in row) {
                return row.province
                  ? row.province
                      .split(',')
                      .map((item, index) => [
                        item,
                        row.city.split(',')[index],
                        row.region.split(',')[index],
                      ])
                  : []
              }
            },
            outputFormat: (val) => {
              return Array.isArray(val) && val.length > 0
                ? {
                    province: val.map((item) => item[0]).join(','),
                    city: val.map((item) => item[1]).join(','),
                    region: val.map((item) => item[2]).join(','),
                  }
                : { province: '', city: '', region: '' }
            },
            str: true,
            rules: { required: true, message: '请选择服务地区' },
          },
          {
            label: '联系方式：',
            id: 'contactTel',
            type: 'input',
            readonly: true,
          },
          {
            label: '身份证正反面：',
            id: 'idCards',
            component: 'el-bus-upload',
            el: {
              listType: 'picture-card',
            },
            commonFormat: true,
            forceDisabled: true,
            readonly: true,
          },
          {
            label: '状态：',
            id: 'status',
            type: 'input',
            str: true,
            readonly: true,
            hidden: (row, item, mode) => mode !== 'view',
          },
          {
            label: '不通过原因：',
            id: 'rejectReason',
            type: 'input',
            el: {
              type: 'textarea',
            },
            readonly: true,
            hidden: (row, item, mode) => mode !== 'view' || row.status !== 'R',
          },
        ],
        extraButtons: [
          {
            text: '审核',
            show: (row) => row.status === 'U',
            atClick: (row) => {
              const district = this.getDistrict(row)
              row.district = district
              row.districtStr = district
              this.$refs.crud.$refs.extraDialog[0].show(row)
              return false
            },
          },
          {
            text: '下载小程序码',
            show: (row) => row.status === 'P',
            atClick: async (row) => {
              if (row.wechatUrl) {
                window.open(row.wechatUrl, '_blank')
              } else {
                const { code, data } = await this.$elBusHttp.request(
                  'flower/api/partner/page/upload/code',
                  {
                    method: 'post',
                    data: {
                      id: row.id,
                    },
                  }
                )
                if (code === 0 && data) {
                  window.open(data, '_blank')
                }
              }
            },
          },
        ],
        extraDialogs: [
          {
            title: '审核',
            readonly: true,
            form: getAuditForm(),
            atConfirm: async (val) => {
              const { code } = await this.$elBusHttp.request(
                'flower/api/partner/page/audit',
                {
                  method: 'post',
                  data: {
                    ...val,
                    rejectReason: val.auditRejectReason,
                  },
                }
              )
              if (code === 0) {
                this.$message.success('操作成功')
              }
            },
          },
        ],
      },
    }
  },
  head() {
    return {
      title: '合伙人列表',
    }
  },
  methods: {
    getDistrict(row) {
      if (row.province) {
        return row.province
          .split(',')
          .map((item, index) =>
            [
              item,
              row.city.split(',')[index],
              row.region.split(',')[index],
            ].join('-')
          )
          .join(',')
      }
      return ''
    },
    onEnabledChange(row, e) {
      const url = 'flower/api/partner/page/isEnable'
      const text = e ? '启用' : '禁用'
      this.$elBusUtil
        .confirm(`确定要${text}这个合伙人吗？`)
        .then(async () => {
          const { code } = await this.$elBusHttp.request(url, {
            params: {
              id: row.id,
            },
          })
          if (code === 0) {
            this.$message.success(`${text}成功`)
            this.$refs.crud.getList()
          }
        })
        .catch(() => {})
    },
  },
}
</script>

<style lang="scss" scoped></style>
